@@ -38,7 +38,7 @@ def run_forecast_ensemble(
         prediction_lag=0.0):
     # Initialize with copy of input date
     dataframe[DATE_COLUMN_NAME] = pd.to_datetime(dataframe[date_column])
-    df = dataframe.sort_values(by=date_column)
+    df = dataframe.copy()
 
     # Creates time series and ensures proper naming and frequency
     frequency = FREQUENCY_MAPPING.get(frequency)
@@ -127,7 +127,6 @@ def run_forecast_ensemble(
             # Replace negative values with the Naive value
             forecast_df = model["forecast_dataframe"]
 
-            model["weight"] = model["weight"] / total_weight
             return_dataframe = pd.merge(
                 left=return_dataframe,
                 right=model["forecast_dataframe"],
@@ -152,11 +151,11 @@ def run_forecast_ensemble(
                     right_index=True)
     # Create Ensemble Predictions
     ensemble_prediction_columns = [column for column in return_dataframe.columns if column.startswith("weighted_predicted_values")]
-    return_dataframe["predicted_values_Ensemble"] = return_dataframe[ensemble_prediction_columns].sum(axis=1, min_count=1)
+    return_dataframe["predicted_values_Ensemble"] = return_dataframe[ensemble_prediction_columns].sum(axis=1, min_count=1) / total_weight
 
     # Create ensemble weighted forecast
     ensemble_forecast_columns = [column for column in return_dataframe.columns if column.startswith("weighted_forecast_values")]
-    return_dataframe["forecast_values_Ensemble"] = return_dataframe[ensemble_forecast_columns].sum(axis=1, min_count=1)
+    return_dataframe["forecast_values_Ensemble"] = return_dataframe[ensemble_forecast_columns].sum(axis=1, min_count=1) / total_weight
     forecast_columns = [column for column in return_dataframe.columns if column.startswith("forecast_values")]
     if prediction_lag != 0:
         return_dataframe = utils.apply_lag(return_dataframe, forecast_columns, prediction_lag)
@@ -164,7 +163,7 @@ def run_forecast_ensemble(
     # Calculate ensemble metrics
     required_columns = ensemble_prediction_columns + ["y"]
     ensemble_train_df = return_dataframe.dropna(subset=required_columns)
-    performance_metrics = utils.get_model_statistics(ensemble_train_df["predicted_values_Ensemble"], ensemble_train_df["y"])
+    performance_metrics = utils.get_model_statistics(ensemble_train_df["y"], ensemble_train_df["predicted_values_Ensemble"])
     consolidated_metrics = utils.consolidate_scores(performance_metrics, ensemble_train_df["y"].mean())
 
     # Filter to only the required columns
