@@ -84,16 +84,10 @@ class GreyKite(BaseModel):
         """
         forecaster = Forecaster()
         self.metadata.freq = frequency
-        forecast_horizon=len(forecast_period_list)
-        if forecast_horizon >= (len(dataframe) / 4):
-            test_horizon = (len(dataframe) / 4) - 1
-        else:
-            test_horizon = forecast_horizon
         result = forecaster.run_forecast_config(  # result is also stored as `forecaster.forecast_result`.
             df=dataframe,
             config=ForecastConfig(
                 model_components_param=ModelComponentsParam(seasonality={"yearly_seasonality": 40}),
-                evaluation_period_param=EvaluationPeriodParam(test_horizon=test_horizon),
                 model_template=ModelTemplateEnum.SILVERKITE.name,
                 coverage=0.95,
                 metadata_param=self.metadata,
@@ -453,6 +447,10 @@ class XGBoost(BaseModel):
 
         # Add in trend and combine
         backtest_output = pd.merge(left=test, right=decomposed_dataframe, how="left", right_index=True, left_index=True)
+        backtest_output["trend"] = utils.get_linear_predictions(
+            backtest_output.reset_index()["trend"],
+            [i for i in range(0, len(backtest_output["trend"]))]
+        )
         backtest_output[VALUE_COLUMN_NAME] = backtest_output[VALUE_COLUMN_NAME] * backtest_output["trend"]
         backtest_output["seasonal_predicted"] = predicted
         backtest_output["predicted"] = backtest_output["trend"] * backtest_output["seasonal_predicted"]
@@ -464,7 +462,10 @@ class XGBoost(BaseModel):
         # Make trend predictions
         trend_history = decomposed_dataframe[~decomposed_dataframe["trend"].isnull()]
         trend_history = trend_history.reset_index(drop=True)["trend"]
-        linear_predictions = utils.get_linear_predictions(trend_history, [i for i in range(0, len(forecast_period_list))])
+        linear_predictions = utils.get_linear_predictions(
+            trend_history,
+            [i for i in range(len(trend_history), len(trend_history) + len(forecast_period_list))]
+        )
         assembled_forecast = pd.DataFrame({
             "period": forecast_period_list,
             "linear": linear_predictions.values,
@@ -615,8 +616,13 @@ class RandomForest(BaseModel):
 
             # add actual observation to history for the next loop
             train = pd.concat([train, pd.DataFrame(row).T])
+
         # Add in trend and combine
         backtest_output = pd.merge(left=test, right=decomposed_dataframe, how="left", right_index=True, left_index=True)
+        backtest_output["trend"] = utils.get_linear_predictions(
+            backtest_output.reset_index()["trend"],
+            [i for i in range(0, len(backtest_output["trend"]))]
+        )
         backtest_output[VALUE_COLUMN_NAME] = backtest_output[VALUE_COLUMN_NAME] * backtest_output["trend"]
         backtest_output["seasonal_predicted"] = predicted
         backtest_output["predicted"] = backtest_output["trend"] * backtest_output["seasonal_predicted"]
@@ -628,7 +634,10 @@ class RandomForest(BaseModel):
         # Make trend predictions
         trend_history = decomposed_dataframe[~decomposed_dataframe["trend"].isnull()]
         trend_history = trend_history.reset_index(drop=True)["trend"]
-        linear_predictions = utils.get_linear_predictions(trend_history, [i for i in range(0, len(forecast_period_list))])
+        linear_predictions = utils.get_linear_predictions(
+            trend_history,
+            [i for i in range(len(trend_history), len(trend_history) + len(forecast_period_list))]
+        )
         assembled_forecast = pd.DataFrame({
             "period": forecast_period_list,
             "linear": linear_predictions.values,
@@ -645,22 +654,29 @@ class SARIMA(BaseModel):
         """Initializes SARIMA model"""
         super().__init__()
         self.__name__ = "SARIMA"
+        self.order = (1, 0, 1)
+        self.seasonal_order = (1, 1, 2, None)
 
     def run(self, dataframe: pd.DataFrame, train_end: datetime, frequency: str, forecast_period_list: list) -> tuple:
         original_dataframe = dataframe.copy()
 
+        if frequency == "W-MON":
+            self.seasonal_order = (1, 1, 2, 52.5)
+        elif frequency == "MS":
+            self.seasonal_order = (1, 1, 2, 12)
+
         # Prepare dataframe for backtest
         backfill_dataframe = utils.create_backfill_time_series(original_dataframe, frequency)
         backfill_dataframe = pd.concat([original_dataframe, backfill_dataframe]).sort_values(by="period")
-        dataframe_backtest = backfill_dataframe.set_index("period").asfreq(frequency)
+        backfill_dataframe = backfill_dataframe.set_index("period").asfreq(frequency)
 
-        # Parse original dataframe for usage later
-        dataframe = original_dataframe.set_index("period").asfreq(frequency)
+        # Prepare dataframe
+        # Decompose time series
+        decomposed_dataframe = utils.get_seasonal_decomposition(backfill_dataframe["y"])
+        decomposed_dataframe = decomposed_dataframe.asfreq(frequency)
 
-        if frequency == "W-MON":
-            m = 52.5
-        elif frequency == "MS":
-            m = 12
+        # Create Time Series Features for stationary
+        dataframe_backtest = pd.DataFrame(decomposed_dataframe.rename(columns={"seasonal": "y"})["y"])
 
         # Split into train and test
         # Check if enough data is provided to train on a full year
@@ -669,14 +685,15 @@ class SARIMA(BaseModel):
             if (dataframe_backtest.index.max() - train_start).days > 540:
                 train_end = train_start + relativedelta(years=1)
         train_mask = dataframe_backtest.index <= train_end
-        train = dataframe_backtest[train_mask]
-        test = dataframe_backtest[~train_mask]
+        train_df = dataframe_backtest[train_mask]
+        train = train_df.reset_index(drop=True)
+        test_df = dataframe_backtest[~train_mask]
+        test = test_df.reset_index(drop=True)
 
         # Create step-forward validation
         predicted = pd.DataFrame()
         previous_index = 0
-        period_horizon = int(len(forecast_period_list) / 10)
-
+        period_horizon = int(len(forecast_period_list))
         if period_horizon <= len(test):
             start = period_horizon
             end = len(test)
@@ -687,7 +704,7 @@ class SARIMA(BaseModel):
             step = len(test)
         backtest_range = range(start, end, step)
         for ii in backtest_range:
-            model = SARIMAX(train, order=(1, 1, 2), seasonal_order=(1, 1, 2, m))
+            model = SARIMAX(train, order=self.order, seasonal_order=self.seasonal_order)
             results = model.fit(method='powell', disp=False)
 
             # Identify subset of test to forecast against
@@ -695,7 +712,8 @@ class SARIMA(BaseModel):
             previous_index = ii
 
             # Create predictions and add to list
-            predictions = pd.DataFrame(index=test_subset.index, data=results.forecast(steps=step).values)
+            predictions = results.forecast(steps=step)
+            predictions = pd.DataFrame(index=test_subset.index, data=predictions.values)
             predicted = pd.concat([predicted, predictions])
 
             # Update training dataset
@@ -703,7 +721,7 @@ class SARIMA(BaseModel):
 
             # Handle final test records
             if ((len(test) - ii) < step) & (len(test) - ii > 0):
-                model = SARIMAX(train, order=(1, 1, 2), seasonal_order=(1, 1, 2, m))
+                model = SARIMAX(train, order=self.order, seasonal_order=self.seasonal_order)
                 results = model.fit(method='powell')
 
                 # Identify subset of test to forecast against
@@ -711,20 +729,50 @@ class SARIMA(BaseModel):
                 train = pd.concat([train, test_subset])
 
                 # Create predictions and add to list
-                predictions = pd.DataFrame(index=test_subset.index,
-                                           data=results.forecast(steps=len(test_subset)).values)
+                predictions = pd.DataFrame(
+                    index=test_subset.index,
+                    data=results.forecast(
+                        steps=len(test_subset)
+                        ).values
+                )
                 predicted = pd.concat([predicted, predictions])
-        predicted[0] = predicted[0].apply(lambda x: x if x > 0 else 1)
+
+        # Add in trend and combine
+        backtest_output = pd.merge(
+            left=test_df,
+            right=decomposed_dataframe,
+            how="left",
+            right_index=True,
+            left_index=True)
+        backtest_output[VALUE_COLUMN_NAME] = backtest_output[VALUE_COLUMN_NAME] * backtest_output["trend"]
+        linear_trend = utils.get_linear_predictions(
+            backtest_output.reset_index()["trend"],
+            [i for i in range(0, len(backtest_output["trend"]))]
+        )
+        backtest_output["linear_trend"] = linear_trend.values
+        backtest_output["seasonal_predicted"] = predicted.values
+        backtest_output["predicted"] = backtest_output["linear_trend"] * backtest_output["seasonal_predicted"]
 
         # Create future forecast
-        model = SARIMAX(dataframe, order=(1, 1, 2), seasonal_order=(1, 1, 2, m))
+        # Make trend predictions
+        trend_history = decomposed_dataframe[~decomposed_dataframe["trend"].isnull()]
+        trend_history = trend_history.reset_index(drop=True)["trend"]
+        linear_predictions = utils.get_linear_predictions(
+            trend_history,
+            [i for i in range(len(trend_history), len(trend_history) + len(forecast_period_list))])
+        # Make seasonal predictions
+        model = SARIMAX(dataframe_backtest, order=self.order, seasonal_order=self.seasonal_order)
         results = model.fit(method='powell', disp=False)
-        predictions = results.forecast(steps=len(forecast_period_list))
+        seasonal_predictions = results.forecast(steps=len(forecast_period_list))
 
-        forecast = pd.Series(index=forecast_period_list, data=predictions)
-        forecast = forecast.apply(lambda x: x if x > 0 else 1)
+        assembled_forecast = pd.DataFrame({
+            "period": forecast_period_list,
+            "linear": linear_predictions.values,
+            "seasonal": seasonal_predictions.values
+        })
+        assembled_forecast.set_index("period", inplace=True)
 
-        return test[VALUE_COLUMN_NAME], predicted[0].values, forecast
+        return backtest_output[VALUE_COLUMN_NAME], backtest_output["predicted"], assembled_forecast["linear"] * assembled_forecast["seasonal"]
 
 
 def initialize_model(model_name: str):
